@@ -91,9 +91,10 @@ def add_handles(
 @click.command()  # pragma: no cover
 @click.option('-f', '--files', default='./editions/*.xml', show_default=True)  # pragma: no cover
 @click.option('-i', '--indices', default='./indices/list*.xml', show_default=True)  # pragma: no cover
+@click.option('-m', '--mention-xpath', default='.//tei:rs[@ref]/@ref', show_default=True)  # pragma: no cover
 @click.option('-t', '--event-title', default='erwähnt in ', show_default=True)  # pragma: no cover
 @click.option('-x', '--title-xpath', default='.//tei:title[@type="main"]/text()', show_default=True)  # pragma: no cover
-def mentions_to_indices(files, indices, event_title, title_xpath):  # pragma: no cover
+def mentions_to_indices(files, indices, mention_xpath, event_title, title_xpath):  # pragma: no cover
     """Console script write pointers to mentions in index-docs"""
     files = sorted(glob.glob(files))
     index_files = sorted(glob.glob(indices))
@@ -112,14 +113,16 @@ def mentions_to_indices(files, indices, event_title, title_xpath):  # pragma: no
         doc_id = doc.any_xpath('./@xml:id')[0]
         doc_uri = f"{doc_base}/{doc_id}"
         doc_title = doc.any_xpath(title_xpath)[0]
-        refs = doc.any_xpath('.//tei:rs[@ref]/@ref')
-        for ref in refs:
-            ref_doc_dict[ref[1:]].append({
+        refs = doc.any_xpath(mention_xpath)
+        for ref in set(refs):
+            if ref.startswith('#'):
+                ref = ref[1:]
+            ref_doc_dict[ref].append({
                 "doc_uri": doc_uri,
                 "doc_path": x,
                 "doc_title": doc_title
             })
-            doc_ref_dict[filename].append(ref[1:])
+            doc_ref_dict[filename].append(ref)
     click.echo(
         click.style(
             f"collected {len(ref_doc_dict.keys())} of mentioned entities from {len(files)} docs",
@@ -157,9 +160,11 @@ def mentions_to_indices(files, indices, event_title, title_xpath):  # pragma: no
 @click.command()  # pragma: no cover
 @click.option('-f', '--files', default='./editions/*.xml', show_default=True)  # pragma: no cover
 @click.option('-i', '--indices', default='./indices/list*.xml', show_default=True)  # pragma: no cover
+@click.option('-m', '--mention-xpath', default='.//tei:rs[@ref]/@ref', show_default=True)  # pragma: no cover
 @click.option('-t', '--event-title', default='erwähnt in ', show_default=True)  # pragma: no cover
 @click.option('-x', '--title-xpath', default='.//tei:title/text()', show_default=True)  # pragma: no cover
-def denormalize_indices(files, indices, event_title, title_xpath):  # pragma: no cover
+@click.option('-b', '--blacklist-ids', default=[], multiple=True, show_default=True)  # pragma: no cover
+def denormalize_indices(files, indices, mention_xpath, event_title, title_xpath, blacklist_ids=[]):  # pragma: no cover
     """Write pointers to mentions in index-docs and copy index entries into docs"""
     files = sorted(glob.glob(files))
     index_files = sorted(glob.glob(indices))
@@ -173,19 +178,23 @@ def denormalize_indices(files, indices, event_title, title_xpath):  # pragma: no
     )
     for x in tqdm.tqdm(files):
         filename = os.path.split(x)[1]
+        if 'list' in filename:
+            continue
         doc = TeiEnricher(x)
         doc_base = doc.any_xpath('./@xml:base')[0]
         doc_id = doc.any_xpath('./@xml:id')[0]
         doc_uri = f"{doc_base}/{doc_id}"
         doc_title = doc.any_xpath(title_xpath)[0]
-        refs = doc.any_xpath('.//tei:rs[@ref]/@ref')
-        for ref in refs:
-            ref_doc_dict[ref[1:]].append({
+        refs = doc.any_xpath(mention_xpath)
+        for ref in set(refs):
+            if ref.startswith('#'):
+                ref = ref[1:]
+            ref_doc_dict[ref].append({
                 "doc_uri": doc_uri,
                 "doc_path": x,
                 "doc_title": doc_title
             })
-            doc_ref_dict[filename].append(ref[1:])
+            doc_ref_dict[filename].append(ref)
     click.echo(
         click.style(
             f"collected {len(ref_doc_dict.keys())} of mentioned entities from {len(files)} docs",
@@ -198,6 +207,8 @@ def denormalize_indices(files, indices, event_title, title_xpath):  # pragma: no
         for ent in ent_nodes:
             ent_id = ent.xpath('@xml:id')[0]
             mention = ref_doc_dict[ent_id]
+            if ent_id in blacklist_ids:
+                continue
             event_list = doc.create_mention_list(mention, event_title=event_title)
             try:
                 list(event_list[0])
@@ -223,10 +234,14 @@ def denormalize_indices(files, indices, event_title, title_xpath):  # pragma: no
         filename = os.path.split(x)[1]
         doc = TeiEnricher(x)
         root_node = doc.any_xpath('.//tei:text')[0]
-        refs = doc.any_xpath('.//tei:rs[@ref]/@ref')
+        refs = doc.any_xpath(mention_xpath)
         ent_dict = defaultdict(list)
-        for ref in refs:
-            ent_id = ref[1:]
+        for ref in set(refs):
+            # print(ref, type(ref))
+            if ref.startswith('#'):
+                ent_id = ref[1:]
+            else:
+                ent_id = ref
             try:
                 index_ent = all_ent_nodes[ent_id]
                 ent_dict[index_ent.tag].append(index_ent)
@@ -249,7 +264,7 @@ def denormalize_indices(files, indices, event_title, title_xpath):  # pragma: no
                 back_node.append(list_org)
                 for ent in ent_dict[key]:
                     list_org.append(ent)
-            if key.endswith('bibl'):
+            if key.startswith('bibl'):
                 list_bibl = ET.Element("{http://www.tei-c.org/ns/1.0}listBibl")
                 back_node.append(list_bibl)
                 for ent in ent_dict[key]:
